/*
 * Copyright (c) 2018 Nordic Semiconductor ASA
 *
 * SPDX-License-Identifier: LicenseRef-BSD-5-Clause-Nordic
 */

#include <zephyr.h>
#include <net/socket.h>
#include <stdio.h>
#include <uart.h>
#include <string.h>

#define MAXLINE 4096
#define HTTP_HOST "ptsv2.com"
#define HTTP_PATH "/t/qtwvg-1562396142/post"
#define HTTP_PORT 80
#define RECV_BUF_SIZE 8192
#define TEST_SIZE 5       


struct k_timer my_timer;

bool read_exec = false;


char recv_buf[RECV_BUF_SIZE + 1];

int blocking_recv(int fd, u8_t *buf, u32_t size, u32_t flags)
{
	int err;
        int count = 0;

	do {
                count++;
                printk("count: %d", count);
		err = recv(fd, buf, size, flags);
                printk("count (under): %d", count);
	} while (err < 0 && errno == EAGAIN && (count<300));

	return err;
}

int blocking_send(int fd, u8_t *buf, u32_t size, u32_t flags)
{
	int err;

	do {
		err = send(fd, buf, size, flags);
	} while (err < 0 && errno == EAGAIN);

	return err;
}

int blocking_connect(int fd, struct sockaddr *local_addr, socklen_t len)
{
	int err;

	do {
		err = connect(fd, local_addr, len);
	} while (err < 0 && errno == EAGAIN);

	return err;
}

void app_http_start(void)
{

        read_exec = true;
	struct sockaddr_in local_addr;
	struct addrinfo *res;

	local_addr.sin_family = AF_INET;
	local_addr.sin_port = htons(0);
	local_addr.sin_addr.s_addr = 0;

	printk("HTTP example\n\r");
	int err = getaddrinfo(HTTP_HOST, NULL, NULL, &res);

	printk("getaddrinfo err: %d\n\r", err);
	((struct sockaddr_in *)res->ai_addr)->sin_port = htons(HTTP_PORT);

        char send_buf[] = "POST /t/qtwvg-1562396142/post? HTTP/1.1\r\n"\
		"Host: ptsv2.com\r\n"\
		"Connection: keep-alive\r\n"\
	        "Content-type: text/plain\r\n"\
		"Content-length: 3\r\n\r\n"\
		"123";
        int send_data_len_post = strlen(send_buf);

	int client_fd = socket(AF_INET, SOCK_STREAM, 0);

	printk("client_fd: %d\n\r", client_fd);
	err = bind(client_fd, (struct sockaddr *)&local_addr,
		   sizeof(local_addr));
	printk("bind err: %d\n\r", err);
	err = blocking_connect(client_fd, (struct sockaddr *)res->ai_addr,
			       sizeof(struct sockaddr_in));
	printk("connect err: %d\n\r", err);

        int num_bytes = send(client_fd, send_buf, send_data_len_post, 0);

	printk("send err: %d\n\r", num_bytes);

	err = close(client_fd);
        freeaddrinfo(res);
        read_exec = false;
}


int main(void)
{



	app_http_start();

	while (1) {
          //5 seconds delay
          k_sleep(5000);
          if(!read_exec){
              app_http_start();
          }
	}
}